function calc_binary_vis2cp_seppa_scale_mpfunc, bin_parameters,dpar,vis2data=vis2data, t3data=t3data, vis2model=vis2model,t3model=t3model,do_wave=do_wave,fit_v2_only=fit_v2_only,fit_t3_only=fit_t3_only

; Read the (u,v) coordinates from an oifits file and compute the
; squared visibilities, triple amplitude, and closure phase.

; CALL TO THE PROGRAM:
; calc_binary_vis2cp, [sepRA, sepDEC, f1, f2, f3{, diam1, diam2}]
;
; INPUT PARAMETERS:
; file_oifits: name of the oifits file
; bin_parameters: array containing parameters of binary system
;     - [sepRA, sepDEC, f1, f2, f3, diam1, diam2] or [sepRA, sepDEC, f1, f2, f3]
;     - (sepRA, sepDEC): separation in (RA, DEC) between components 2 and 1 in mas
;     - f1, f2, f3: fractional flux contributions of components 1, 2,
;       and incoherent flux contribution f3
;       (f1 + f2 + f3) = 1.0
;     - Component diameters as mas.  If diameters are unresolved,
;       enter 0.0 if unresolved or leave out (enter [binsep, pa, fr] only).
; do_wave: set to 1 to apply filter passband, set to 0 for monochromatic.
;
; This routine calls the following programs:
;    calc_binary_scale_visph_xy.pro  (GHS)
;    extract_vis2data.pro   (JDM)
;    extract_t3data.pro     (JDM)
;
; NOTE!!!! The separations must be in mas !!!!
;
; REVISON NOTES:
; 02Oct2009 - Program started by Gail H. Schaefer.
; 30Jun2017 - GHS added option to include bandwidth smearing

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Are the filter specifications defined?                                    ;
; keyword_set returns True (1) if filter is defined, False (0) if undefined ;
; do_wave is set to 1 or 0                                                  ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; If do_wave not defined, then set to monochromatic:
ans_wave = keyword_set(do_wave)
if (ans_wave eq 0) then begin
   do_wave = 0  
endif

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Check if fit_v2_only and fit_t3_only keywords are defined.  ;
; If not, then set equal to 0, to fit to both V2 and T3 data. ;
; True (1) and False (0).                                     ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

if (keyword_set(fit_v2_only) eq 0) then fit_v2_only = 0
if (keyword_set(fit_t3_only) eq 0) then fit_t3_only = 0

; If both fit_v2_only and fit_t3_only are set to true, then
; turn both off to fit to both visibilities and closure phases.
if (fit_v2_only) and (fit_t3_only) then begin
   fit_v2_only = 0
   fit_t3_only = 0
endif

numvis2 = n_elements(vis2data.u)
numt3 = n_elements(t3data.u1)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Compute squared visibilities ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; Integrate over wavelength
if (do_wave) then begin
   calc_binary_scale_visph_xy, bin_parameters, vis2data.u, vis2data.v, vis, phase, wcent=vis2data.eff_wave, wband=vis2data.eff_band
endif else begin
; No integration over wavelength
   calc_binary_scale_visph_xy, bin_parameters, vis2data.u, vis2data.v, vis, phase
endelse

binary_vis2data = vis^2

;print,'V^2:',binary_vis2data
vis2model.vis2data=binary_vis2data
vis2model.vis2err=0.

;;;;;;;;;;;;;;;;;;;;;;;;;;
; Compute closure phases ;
;;;;;;;;;;;;;;;;;;;;;;;;;;

; Integrate over wavelength:
if (do_wave) then begin
   calc_binary_scale_visph_xy, bin_parameters, t3data.u1, t3data.v1, vis1, phase1, wcent=t3data.eff_wave, wband=t3data.eff_band
   calc_binary_scale_visph_xy, bin_parameters, t3data.u2, t3data.v2, vis2, phase2, wcent=t3data.eff_wave, wband=t3data.eff_band
   calc_binary_scale_visph_xy, bin_parameters, t3data.u3, t3data.v3, vis3, phase3, wcent=t3data.eff_wave, wband=t3data.eff_band
endif else begin
   ; No integration over wavelength:
   calc_binary_scale_visph_xy, bin_parameters, t3data.u1, t3data.v1, vis1, phase1
   calc_binary_scale_visph_xy, bin_parameters, t3data.u2, t3data.v2, vis2, phase2
   calc_binary_scale_visph_xy, bin_parameters, t3data.u3, t3data.v3, vis3, phase3
endelse

binary_t3amp = vis1*vis2*vis3
binary_t3phi = phase1+phase2+phase3

; Keep closure phases between -180 and 180

for i=0, numt3-1 do $
   while (binary_t3phi(i) ge 180.0) do binary_t3phi(i)=binary_t3phi(i)-360.0

for i=0, numt3-1 do $
   while (binary_t3phi(i) le -180.0) do binary_t3phi(i)=binary_t3phi(i)+360.0

;print,'Phase 1:',phase1
;print,'Phase 2:',phase2
;print,'Phase 3:',phase3

;print,'T3Amp:',binary_t3amp
;print,'Closure Phase:',binary_t3phi
t3model.t3amp=binary_t3amp
t3model.t3amperr=0.
t3model.t3phi=binary_t3phi
t3model.t3phierr=0.

if (fit_v2_only) then begin
   ; Fit only visibilities:
   residuals = [ (vis2data.vis2data - vis2model.vis2data)/(vis2data.vis2err)]
endif else begin
if (fit_t3_only) then begin
   ; Fit only closure phases:
   residuals = [angle_diff(t3data.t3phi,t3model.t3phi)/t3data.t3phierr]
endif else begin
   ; Fit both closure phases and visibilities:
   residuals = [ (vis2data.vis2data - vis2model.vis2data)/(vis2data.vis2err),$
                 angle_diff(t3data.t3phi,t3model.t3phi)/t3data.t3phierr]
endelse
endelse

return,residuals

end
