function ellipse_mpfunc, params, x=x, y=y

; Fit an ellipse to a set of (x,y) data
;
; First shift coordinates in (x,y) reference frame:
; xshift = x - x0
; yshitt = y - y0
;
; Equation for an ellipse:
; (x'/a)^2 + (y'/b)^2 = 1
;
; In this case, we want to rotate the coordinate system
; to align with the major and minor axes of the ellipse
; with the x' and y' axes of the coordinate system
; (equivalent to rotating measured ellipse by -theta):
;
; x' =  xshift*cos(theta) + yshift*sin(theta)
; y' = -xshift*sin(theta) + yshift*cos(theta)
;
; params = [a,b,x0,y0,theta]
;
; NOTE: This gives center coordinates (x0,y0) in RA and DEC,
;       not in the rotated reference frame.
;
; Began 2015Sep02 - GHS


; Compute residuals for minimizing ellipse fit

a = params(0)
b = params(1)
xcent = params(2)
ycent = params(3)
theta = params(4)

xshift = x - xcent
yshift = y - ycent

xp =  xshift*cos(theta) + yshift*sin(theta)
yp =  -xshift*sin(theta) + yshift*cos(theta)

residual = (xp/a)^2 + (yp/b)^2 - 1

;xp =  x*cos(theta) + y*sin(theta)
;yp =  -x*sin(theta) + y*cos(theta)

;residual = ((xp-xcent)/a)^2 + ((yp-ycent)/b)^2 - 1

return, residual

;stop,'Type .cont to continue'

end
